# FairSwap

The directory `lEthDev-FairSwap` contains the original FairSwap example smart contract source code
as it was published by the authors of the original FairSwap paper.

> Dziembowski, S., Eckey, L., & Faust, S. (2018). Fairswap: How to fairly exchange digital goods. In Proceedings of the ACM Conference on Computer and Communications Security. https://doi.org/10.1145/3243734.3243857

The original repository is available at https://github.com/lEthDev/FairSwap.
Use kindly permitted by Lisa Eckey (16. April 2020).
